const api = require('../../utils/api');

// 获得BackgroundAudioManager
const audioPlayer = wx.getBackgroundAudioManager();

Page({
  data: {
    SERVER_PATH: api.SERVER_PATH,
    curAudioDiaryIndex : -1
  },
  onShow: async function () {
    const firstPageData = await api.request('/getFirstPageData');
    // 将日记音频的相对路径转换为完整的url
    firstPageData.diaries.forEach(diary => {
      if (!diary.audioPath) return;
      diary.audioPath = api.SERVER_PATH + diary.audioPath;
    });
    this.setData({...firstPageData});

    // 监听BackgroundAudioManager的各种事件
    // 开始播放
    audioPlayer.onPlay(() => {
      this.setData({[`diaries[${this.data.curAudioDiaryIndex}].isAudioPlaying`]: true});
    });
    // 播放暂停
    audioPlayer.onPause(() => {
      this.setData({[`diaries[${this.data.curAudioDiaryIndex}].isAudioPlaying`]: false});
    });
    // 播放停止
    audioPlayer.onStop(() => {
      this.setData({[`diaries[${this.data.curAudioDiaryIndex}].isAudioPlaying`]: false, [`diaries[${this.data.curAudioDiaryIndex}].audioElapsed`]: 0});
    });
    // 播放结束
    audioPlayer.onEnded(() => {
      this.setData({[`diaries[${this.data.curAudioDiaryIndex}].isAudioPlaying`]: false, [`diaries[${this.data.curAudioDiaryIndex}].audioElapsed`]: 0});
    });
    // 播放进度变化
    audioPlayer.onTimeUpdate(() => {
      // 若当前用户没有正在拖动播放滑动, 则播放器的时候随播放进度变化
      if (!this.data.isChangingAudioPos) {
        this.setData({[`diaries[${this.data.curAudioDiaryIndex}].audioElapsed`]: audioPlayer.currentTime});
      }
    });
  },
  // 音频播放/暂停
  audioPlayOrPause: function (e) {
    const index = e.currentTarget.dataset.index;
    const diary = this.data.diaries[index];

    // 若当前点击的音频正在播放则暂停并返回
    if (diary.isAudioPlaying) return audioPlayer.pause();

    // 若当前有其它音频正在播放, 则暂停
    const curAudioDiaryIndex = this.data.curAudioDiaryIndex;
    if (curAudioDiaryIndex >= 0 && curAudioDiaryIndex !== index) {
      audioPlayer.pause();
      // 因 audioPlayer.pause() 为异步执行, 此处须主动更新现正播放的音频播放状态
      this.setData({[`diaries[${curAudioDiaryIndex}].isAudioPlaying`]: false});
    }

    // 原先无音频正在播放或现需切换至别的音频, 则设置新的音频播放信息
    if (!audioPlayer.src || audioPlayer.src !== diary.audioPath) {
      audioPlayer.src = diary.audioPath;
      audioPlayer.title = diary.title;
      audioPlayer.singer = diary.author;
      audioPlayer.coverImgUrl = api.SERVER_PATH + diary.cover;

      // 原先此音频已播放了一部分, 从上次暂停位置继续
      if (diary.audioElapsed > 0) audioPlayer.seek(diary.audioElapsed);

      // 记录当前正在播放的音频
      this.setData({ curAudioDiaryIndex: index });
    }

    // 开始播放音频
    audioPlayer.play();
  },
  // 用户正在拖动播放进度滑块
  onChangingAudioPos: function(e) {
    const curAudioDiaryIndex = this.data.curAudioDiaryIndex;           
    this.setData({ 
      isChangingAudioPos: true,                                           // 标记当前用户正在播放进度滑块
      [`diaries[${curAudioDiaryIndex}].audioElapsed`]: e.detail.value     // 当前播放时长与滑块位置同步
    });
  },
  // 进度滑块位置改变回调函数
  onChangeAudioPos: function(e) {
    const pos = e.detail.value;                   // 滑块当前位置
    audioPlayer.seek(pos);                        // 将播放点跳至滑块对应位置
    if (audioPlayer.paused) audioPlayer.play();   // 若音频处于暂停状态, 拖动结束后自动开始播放

    this.setData({ isChangingAudioPos: false});   // 记录当前已结束滑块拖动
  },
  // 打卡 
  onAddDiary: function() {
    wx.navigateTo({
      url: '/pages/diary/diary'
    });
  }
})