// 服务器地址
const SERVER_API = 'http://localhost:8000';

// 向服务器发送http/https请求
const request = (url, data) => {
  return new Promise((resolve, reject) => {
    wx.showLoading({ title: '加载数据中...'});
    wx.request({
      url: `${SERVER_API}${url}`,
      method: 'POST',
      data: data || {},
      success: (resp) => {
        wx.hideLoading();
        if (resp.statusCode === 200) {
          resolve(resp.data);  
        } else {
          wx.showToast({ title: '网络请求失败: ' + resp.statusCode, icon: 'none' });
        }
      },
      fail: (err) => {
        wx.showToast({ title: '网络请求失败', icon: 'none' });
        reject(err);
      }
    });
  });
}

// 上传文件
const uploadFile = (url, data, localFilePath, processCallback) => {
  return new Promise((resolve, reject) => {
    wx.showLoading({ title: '文件上传中...'});
    const uploadTask = wx.uploadFile({
      url: `${SERVER_API}${url}`,
      method: 'POST',
      filePath: localFilePath,
      name: 'file',
      formData: data || {},
      header: {
        "Content-Type": "multipart/form-data",
      },
      success: (resp) => {
        wx.hideLoading();
        if (resp.statusCode === 200) {
          resolve(resp.data);  
        } else {
          wx.showToast({ title: '上传文件失败: ' + resp.statusCode, icon: 'none' });
        }
      },
      fail: (err) => {
        wx.showToast({ title: '上传文件失败', icon: 'none' });
        reject(err);
      }
    });
    uploadTask.onProgressUpdate((resp) => {
      if (processCallback) processCallback(resp, uploadTask);
    })
  });
}

module.exports = {
  SERVER_PATH: SERVER_API + '/',
  request,
  uploadFile
}